@@ -1,12 +1,9 @@
 import numpy as np
 import pandas as pd
 from copy import deepcopy
-import numpy_groupies as npg
-# import numpy_indexed as npi
 import time
 import sys
 import os
-sys.path.append(os.path.abspath("/home/carlos/Documents/apps/numpy_dataframe/"))
 import numpy_dataframe as npd
 import random
 import string
@@ -27,6 +24,7 @@ class Awk_command:
         super(Awk_command, self).__setattr__('type', "")
         super(Awk_command, self).__setattr__('persistance_in_time', "continuous")
         super(Awk_command, self).__setattr__('persistance_after_execution', "ephemeral")
+        super(Awk_command, self).__setattr__('id', get_random_string(20))
     def __getattr__(self, name):
         return super(Awk_command, self).__getattr__(name)
     def __setattr__(self, name, value):
@@ -301,7 +299,7 @@ class DataFrame:
 #             rows = np.array(rows)
 #         rows_str = np.array2string(rows,separator="\n")
 #         rows_str = rows_str[1:len(rows_str)-1]
-#         path_rows = "/home/carlos/.tmp/rows_" + self.id + ".txt"
+#         path_rows = os.path.expanduser('~') + "/.tmp/rows_" + self.id + ".txt"
 #         command = "echo '" + rows_str + "'>" + path_rows
 #         os.system(command)
         variables = "-v header=\"has_header\" -v min_row=\"" + str(min_row) + "\" -v max_row=\"" + str(max_row) + "\" "
@@ -334,7 +332,7 @@ class DataFrame:
         ' """
         awk_command.command = command
         awk_command.priority = 1
-        awk_command.type = "get_rows"
+        awk_command.type = "get_rows_range"
         self.commands.append(awk_command)
         __ddf__ = deepcopy(self)
         __ddf__.__settle_commands__()
@@ -351,7 +349,10 @@ class DataFrame:
 
             rows_str = np.array2string(rows,separator="\n")
             rows_str = rows_str[1:len(rows_str)-1]
-            path_rows = "/home/carlos/.tmp/rows_" + self.id + ".txt"
+            if not os.path.exists(os.path.expanduser('~') + "/.tmp/"):
+                os.mkdir(os.path.expanduser('~') + "/.tmp/")
+                print("Creating folder ",os.path.expanduser('~') + "/.tmp/")
+            path_rows = os.path.expanduser('~') + "/.tmp/rows_" + self.id + "_" + awk_command.id + ".txt"            
             command = "echo '" + rows_str + "'>" + path_rows
             os.system(command)
             variables = "-v header=\"has_header\" -v min_row=\"" + str(min(rows)) + "\" -v max_row=\"" + str(max(rows)) + "\" -v length_rows=\"" + str(len(rows)) + "\" "
@@ -419,7 +420,10 @@ class DataFrame:
 
         cols_str = np.array2string(cols,separator="\n")
         cols_str = cols_str[1:len(cols_str)-1]
-        path_cols = "/home/carlos/.tmp/cols_" + self.id + ".txt"
+        if not os.path.exists(os.path.expanduser('~') + "/.tmp/"):
+            os.mkdir(os.path.expanduser('~') + "/.tmp/")
+            print("Creating folder ",os.path.expanduser('~') + "/.tmp/")
+        path_cols = os.path.expanduser('~') + "/.tmp/cols_" + self.id + "_" + awk_command.id + ".txt"
         command = "echo '" + cols_str + "' | sort | xargs -I {} echo \"{}\" >" + path_cols
         os.system(command)
         variables = "-v header=\"has_header\" -v min_col=\"" + str(min(cols)) + "\" -v max_col=\"" + str(max(cols)) + "\" "
@@ -483,7 +487,29 @@ class DataFrame:
         for command in self.commands:
             if command.persistance_after_execution != "ephemeral":
                 new_commands.append(command)
+            else:
+                if command.type == "get_cols":
+                    path_cols = os.path.expanduser('~') + "/.tmp/cols_" + self.id + "_" + command.id + ".txt"
+                    if os.path.exists(path_cols):
+                        os.remove(path_cols)
+                if command.type == "get_rows":
+                    path_rows = os.path.expanduser('~') + "/.tmp/rows_" + self.id + "_" + command.id + ".txt"
+                    if os.path.exists(path_rows):
+                        os.remove(path_rows)
+                
         self.commands = new_commands
+        
+    def clear_all_commands(self):
+        for command in self.commands:            
+            if command.type == "get_cols":
+                path_cols = os.path.expanduser('~') + "/.tmp/cols_" + self.id + "_" + command.id + ".txt"
+                if os.path.exists(path_cols):
+                    os.remove(path_cols)
+            if command.type == "get_rows":
+                path_rows = os.path.expanduser('~') + "/.tmp/rows_" + self.id + "_" + command.id + ".txt"
+                if os.path.exists(path_rows):
+                    os.remove(path_rows)
+        self.commands = []
 
     def __settle_commands__(self):
         for command in self.commands:
@@ -823,4 +849,4 @@ class DataFrame:
         self.commands.append(awk_command)
         self.values()
         self.path = path_output
-        self.commands = []
+        self.clear_all_commands()
